@@ -24,7 +24,7 @@ using namespace KCalendarCore;
 
 namespace
 {
-static const char mySuspensedGroupName[] = "Suspended";
+const char mySuspensedGroupName[] = "Suspended";
 }
 
 KalendarAlarmClient::KalendarAlarmClient(QObject *parent)
@@ -65,7 +65,7 @@ KalendarAlarmClient::KalendarAlarmClient(QObject *parent)
         });
     }
 
-    KConfigGroup alarmGroup(m_config, QStringLiteral("Alarms"));
+    KConfigGroup const alarmGroup(m_config, QStringLiteral("Alarms"));
     mLastChecked = alarmGroup.readEntry("CalendarsLastChecked", QDateTime::currentDateTime().addDays(-9));
 
     restoreSuspendedFromConfig();
@@ -89,11 +89,11 @@ void KalendarAlarmClient::setupAkonadi()
     checkAlarms();
 }
 
-void checkAllItems(KCheckableProxyModel *model, const QModelIndex &parent = QModelIndex())
+static void checkAllItems(KCheckableProxyModel *model, const QModelIndex &parent = QModelIndex())
 {
     const int rowCount = model->rowCount(parent);
     for (int row = 0; row < rowCount; ++row) {
-        QModelIndex index = model->index(row, 0, parent);
+        QModelIndex const index = model->index(row, 0, parent);
         model->setData(index, Qt::Checked, Qt::CheckStateRole);
 
         if (model->rowCount(index) > 0) {
@@ -178,7 +178,7 @@ void KalendarAlarmClient::askAndSuspend(AlarmNotification *notification,
 void KalendarAlarmClient::showIncidence(const QString &uid, const QDateTime &occurrence, const QString &xdgActivationToken)
 {
     KConfig cfg(QStringLiteral("defaultcalendarrc"));
-    KConfigGroup grp(&cfg, QStringLiteral("General"));
+    KConfigGroup const grp(&cfg, QStringLiteral("General"));
     const auto appId = grp.readEntry(QStringLiteral("ApplicationId"), QString());
     if (appId.isEmpty()) {
         return;
@@ -198,7 +198,7 @@ void KalendarAlarmClient::showIncidence(const QString &uid, const QDateTime &occ
             const QString objectName = QLatin1Char('/') + kontactPlugin + "_PimApplication"_L1;
             QDBusInterface iface(appId, objectName, QStringLiteral("org.kde.PIMUniqueApplication"), QDBusConnection::sessionBus());
             if (iface.isValid()) {
-                QStringList arguments({kontactPlugin});
+                QStringList const arguments({kontactPlugin});
                 iface.call(QStringLiteral("newInstance"), QByteArray(), arguments, QString());
             }
         }
@@ -403,7 +403,8 @@ KalendarAlarmClient::occurrenceForAlarm(const KCalendarCore::Incidence::Ptr &inc
     // Alarm time is defined by an offset from the event start or end time.
     // Find the offset from the event start time, which is also used as the
     // offset from the recurrence time.
-    Duration offset(0), endOffset(0);
+    Duration offset(0);
+    Duration endOffset(0);
     if (alarm->hasStartOffset()) {
         offset = alarm->startOffset();
     } else if (alarm->hasEndOffset()) {
